]> git.donarmstrong.com Git - mothur.git/blobdiff - geom.h
changed random forest output filename
[mothur.git] / geom.h
diff --git a/geom.h b/geom.h
index 56bc112d938faadc7efb2fe3e9faca12ca15ac79..a07676b6573ada920e9770d462ddbcd8b8be196d 100644 (file)
--- a/geom.h
+++ b/geom.h
@@ -6,12 +6,12 @@
  *  Mothur
  *
  *  Created by Thomas Ryabin on 2/23/09.
- *  Copyright 2009 __MyCompanyName__. All rights reserved.
+ *  Copyright 2009 Schloss Lab UMASS Amherst. All rights reserved.
  *
  */
 #include "calculator.h"
 
/* This class implements the LogSD estimator on single group. 
 It is a child of the calculator class. */
 
 /***********************************************************************/
@@ -19,10 +19,12 @@ It is a child of the calculator class. */
 class Geom : public Calculator  {
        
 public:
-       Geom() : Calculator("geom", 3) {};
-       EstOutput getValues(SAbundVector*);
-       EstOutput getValues(SharedRAbundVector*, SharedRAbundVector*) {return data;};
 
+       Geom() : Calculator("geometric", 3, false) {};
+
+       EstOutput getValues(SAbundVector*);
+       EstOutput getValues(vector<SharedRAbundVector*>) {return data;};
+       string getCitation() { return "http://www.mothur.org/wiki/Geometric"; }
 private:
        double kEq(double, double);
        RAbundVector getRAbundVector(SAbundVector*);
@@ -6,12 +6,12 @@
 #include "calculator.h"
 
-/* This class implements the LogSD estimator on single group. 
+/* This class implements the geometric estimator on single group. 
 It is a child of the calculator class. */
 